@@ -1,9 +1,13 @@
 package Pfacter::macaddress;
 
+#
+
 sub pfact {
     my $self  = shift;
     my ( $p ) = shift->{'pfact'};
 
+    my ( $r );
+
     for ( $p->{'kernel'} ) {
         /AIX/ && do {
             my ( $d, @i );
@@ -18,7 +22,7 @@ sub pfact {
                     push @i, "$d=$1" if /(\w+\:\w+\:\w+\:\w+\:\w+\:\w+)/;
                 }
 
-                return join ' ', sort @i;
+                $r = join ' ', sort @i;
             }
         };
 
@@ -27,30 +31,29 @@ sub pfact {
 
             if ( -e '/sbin/ifconfig' ) {
                 open( F, '/sbin/ifconfig -a |' );
+                my ( @F ) = <F>;
+                close( F );
+
+                foreach ( @F ) {
+                    $p->{'kernel'} =~ /Darwin|FreeBSD|SunOS/ && do {
+                        $d = $1 if /^(\w+)\:/;
+                        push @i, "$d=$1"
+                            if /ether\s+(\w+\:\w+\:\w+\:\w+\:\w+\:\w+)/;
+                    };
+
+                    $p->{'kernel'} =~ /Linux/ && do {
+                        $d = $1 if ( /^(\w+)\s+/ || /^(\w+:\d+)\s+/ );
+                        push @i, "$d=$1"
+                            if /HWaddr\s+(\w+\:\w+\:\w+\:\w+\:\w+\:\w+)/;
+                    };
+                }
+
+                $r = join ' ', sort @i;
             }
-            else {
-                return qq((kernel not supported));
-            }
-
-            my ( @F ) = <F>;
-            close( F );
-
-            foreach ( @F ) {
-                $p->{'kernel'} =~ /Darwin|FreeBSD|SunOS/ && do {
-                    $d = $1 if /^(\w+)\:/;
-                    push @i, "$d=$1" if /ether\s+(\w+\:\w+\:\w+\:\w+\:\w+\:\w+)/;
-                };
-
-                $p->{'kernel'} =~ /Linux/ && do {
-                    $d = $1 if ( /^(\w+)\s+/ || /^(\w+:\d+)\s+/ );
-                    push @i, "$d=$1" if /HWaddr\s+(\w+\:\w+\:\w+\:\w+\:\w+\:\w+)/;
-                };
-            }
-
-            return join ' ', sort @i;
         };
 
-        return qq((kernel not supported));
+        if ( $r ) { return( $r ); }
+        else      { return( 0 ); }
     }
 }
 
